.. highlight:: shell

============
Installation
============


Stable release
--------------

We currently don't support installation from PyPI.
Please see next section for installation from source at this point.

From sources
------------

The sources for CompNeuro can be downloaded from the `Github repo`_.

You can either clone the public repository:

.. code-block:: console

    $ git clone git://github.com/TK-21st/compneuro

Or download the `tarball`_:

.. code-block:: console

    $ curl -OJL https://github.com/TK-21st/compneuro/tarball/master

Once you have a copy of the source, you can install it with:

.. code-block:: console

    $ python setup.py install


.. _Github repo: https://github.com/TK-21st/compneuro
.. _tarball: https://github.com/TK-21st/compneuro/tarball/master
